==> 0.0.45.tar.gz: lib/utils/date_util.dart <==
import 'package:get/get.dart';
import 'package:intl/intl.dart';

class DateUtil {
  static DateTime toDate(String date) {
    return DateTime.parse(date);
  }

  /// 29/09/2021
  static String format(DateTime date) {
    DateFormat f = DateFormat.yMd(Get.locale!.toLanguageTag());
    return f.format(date);
  }

  /// 29 DE SETEMBRO DE 2021
  static String formatExtenso(DateTime date) {
    DateFormat f = DateFormat.yMMMMd(Get.locale!.toLanguageTag());
    return f.format(date);
  }

  /// CONVERTE UTC PARA DATA LOCAL E FORMATA 29/09/2021
  static String utfToLocalDateFormat(String date) {
    if (date.isEmpty) return '';
    var dateTime = DateFormat("yyyy-MM-dd'T'HH:mm:ss").parse(date, true);
    return format(dateTime.toLocal());
  }

  /// CONVERTE UTC PARA DATA LOCAL E FORMATA 29 DE SETEMBRO DE 2021
  static String utfToLocalDateFormatExtenso(String date) {
    if (date.isEmpty) return '';
    var dateTime = DateFormat("yyyy-MM-dd'T'HH:mm:ss").parse(date, true);
    return formatExtenso(dateTime.toLocal());
  }

  static String formatDateTimeToString(String date) {
    if (date.isEmpty) return '';
    return DateFormat.yMd(Get.locale!.toLanguageTag())
        .add_jms()
        .format(toDate(date));
  }

  static String formatDateTimeToStringExtenso(String date) {
    if (date.isEmpty) return '';
    return DateFormat.yMMMMd(Get.locale!.toLanguageTag())
        .add_jms()
        .format(toDate(date));
  }

  static String formatDateTimeToDate(DateTime date) {
    return DateFormat.yMd(Get.locale!.toLanguageTag()).add_jms().format(date);
  }

  static String formatDate(String date) {
    if (date.isEmpty) return '';
    DateFormat f = DateFormat.yMd(Get.locale!.toLanguageTag());
    DateTime dt = toDate(date);
    return f.format(dt);
  }

  static String formatDateMesAno(String date) {
    if (date.isEmpty) return '';
    DateFormat f = DateFormat.yM(Get.locale!.toLanguageTag());
    DateTime dt = toDate(date);
    return f.format(dt);
  }

  static String javaFormat(DateTime date) {
    final f = new DateFormat('yyyy-MM-ddTHH:mm');
    return f.format(date);
  }

  static String sqlDateFormat(String date) {
    if (date.isEmpty) return '';
    DateFormat f = DateFormat.yMd(Get.locale!.toLanguageTag());
    DateTime dt = toDate(date);
    return f.format(dt);
  }

  static DateTime utfToLocalDate(String date) {
    if (date.isEmpty) return DateTime.now();
    var dateTime = DateFormat("yyyy-MM-dd'T'HH:mm:ss").parse(date, true);
    return dateTime.toLocal();
  }

  static String toUTCDate(String date) {
    if (date.isEmpty) return '';
    return DateTime.parse(date).toUtc().toIso8601String();
  }
}

==> 0.0.46.tar.gz: lib/utils/date_util.dart <==
import 'package:get/get.dart';
import 'package:intl/intl.dart';

class DateUtil {
  static DateTime toDate(String date) {
    return DateTime.parse(date);
  }

  /// 29/09/2021
  static String format(DateTime date) {
    DateFormat f = DateFormat.yMd(Get.locale!.toLanguageTag());
    return f.format(date);
  }

  /// 29 DE SETEMBRO DE 2021
  static String formatExtenso(DateTime date) {
    DateFormat f = DateFormat.yMMMMd(Get.locale!.toLanguageTag());
    return f.format(date);
  }

  /// CONVERTE UTC PARA DATA LOCAL E FORMATA 29/09/2021
  static String utfToLocalDateFormat(String date) {
    if (date.isEmpty) return '';
    var dateTime = DateFormat("yyyy-MM-dd'T'HH:mm:ss").parse(date, true);
    return format(dateTime.toLocal());
  }

  /// CONVERTE UTC PARA DATA LOCAL E FORMATA 29 DE SETEMBRO DE 2021
  static String utfToLocalDateFormatExtenso(String date) {
    if (date.isEmpty) return '';
    var dateTime = DateFormat("yyyy-MM-dd'T'HH:mm:ss").parse(date, true);
    return formatExtenso(dateTime.toLocal());
  }

  static String formatDateTimeToString(String date) {
    if (date.isEmpty) return '';
    return DateFormat.yMd(Get.locale!.toLanguageTag())
        .add_jm()
        .format(toDate(date));
  }

  static String formatDateTimeToStringExtenso(String date) {
    if (date.isEmpty) return '';
    return DateFormat.yMMMMd(Get.locale!.toLanguageTag())
        .add_jm()
        .format(toDate(date));
  }

  static String formatDateTimeToDate(DateTime date) {
    return DateFormat.yMd(Get.locale!.toLanguageTag()).add_jm().format(date);
  }

  static String formatDate(String date) {
    if (date.isEmpty) return '';
    DateFormat f = DateFormat.yMd(Get.locale!.toLanguageTag());
    DateTime dt = toDate(date);
    return f.format(dt);
  }

  static String formatDateMesAno(String date) {
    if (date.isEmpty) return '';
    DateFormat f = DateFormat.yM(Get.locale!.toLanguageTag());
    DateTime dt = toDate(date);
    return f.format(dt);
  }

  static String javaFormat(DateTime date) {
    final f = new DateFormat('yyyy-MM-ddTHH:mm');
    return f.format(date);
  }

  static String sqlDateFormat(String date) {
    if (date.isEmpty) return '';
    DateFormat f = DateFormat.yMd(Get.locale!.toLanguageTag());
    DateTime dt = toDate(date);
    return f.format(dt);
  }

  static DateTime utfToLocalDate(String date) {
    if (date.isEmpty) return DateTime.now();
    var dateTime = DateFormat("yyyy-MM-dd'T'HH:mm:ss").parse(date, true);
    return dateTime.toLocal();
  }

  static String toUTCDate(String date) {
    if (date.isEmpty) return '';
    return DateTime.parse(date).toUtc().toIso8601String();
  }
}
